@@ -15,11 +15,11 @@ URI::ParseSearchString - parse search engine referrer URLs and extract keywords
 
 =head1 VERSION
 
-Version 3.442  (Minecraft edition)
+Version 3.5  (Diablo 3 edition)
 
 =cut
 
-our $VERSION = '3.442';
+our $VERSION = '3.5';
 
 =head1 SYNOPSIS
 
@@ -399,6 +399,9 @@ my $RH_LOOKUPS = {
    'rediff.com'             => { name => 'Rediff',           q => 'MT' },
    'guruji.com'             => { name => 'Guruji',           q => 'q'  },
    
+   'isohunt.com'            => { name => 'Isohunt',          q => 'ihq' },
+   'btjunkie.org'           => { name => 'BT Junkie',        q => 'q' },
+   'torrentz.eu'            => { name => 'Torrentz',         q => 'f' }
    
 };
 
@@ -473,6 +476,8 @@ sub _uri {
 	
     my $host = $uri->host;
     
+    return unless defined($host) && $host;
+    
    if ( $host =~ m/(feedster|technorati)\.com$/ ){
 	   $uri->query_form( q => ( $uri->path_segments)[-1]);
 	}
@@ -534,8 +539,9 @@ sub findEngine {
   ## create a URI object
   
   my ($uri,$hostname) = $self->_uri( $string );
-  return unless defined($uri);
-	
+  return unless defined($uri) && $uri;
+  return unless defined($hostname) && $hostname;
+  
   my $canonical = $self->{'engines'}->{$hostname}->{'name'};
 	
   return ($hostname,$canonical);
